import { HttpClient, HttpHeaders, HttpResponse, HttpEvent, HttpParameterCodec, HttpContext } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApplicationListIdpModel } from '../model/applicationList';
import { ApplicationWithSecretIdpModel } from '../model/applicationWithSecret';
import { PostBankApplicationIdpModel } from '../model/postBankApplication';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class BankApplicationsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    encoder: HttpParameterCodec;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    private addToHttpParams;
    private addToHttpParamsRecursive;
    /**
     * Create bank application
     * Creates a bank OAuth2 application.  Required scope: **bank_applications:execute**
     * @param postBankApplicationIdpModel
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createBankApplication(postBankApplicationIdpModel: PostBankApplicationIdpModel, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<ApplicationWithSecretIdpModel>;
    createBankApplication(postBankApplicationIdpModel: PostBankApplicationIdpModel, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<ApplicationWithSecretIdpModel>>;
    createBankApplication(postBankApplicationIdpModel: PostBankApplicationIdpModel, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<ApplicationWithSecretIdpModel>>;
    /**
     * Delete bank application
     * Deletes an application.Required scope: **bank_applications:execute**
     * @param clientId Identifier for the application.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteBankApplication(clientId: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<any>;
    deleteBankApplication(clientId: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<any>>;
    deleteBankApplication(clientId: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<any>>;
    /**
     * List bank applications
     * Retrieve a list of bank OAuth2 applications.  Required scope: **banks:read**
     * @param page The page index to retrieve.
     * @param perPage The number of entities per page to return.
     * @param bankGuid Bank guid to list applications for.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    listBankApplications(page?: string, perPage?: string, bankGuid?: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<ApplicationListIdpModel>;
    listBankApplications(page?: string, perPage?: string, bankGuid?: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<ApplicationListIdpModel>>;
    listBankApplications(page?: string, perPage?: string, bankGuid?: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<ApplicationListIdpModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BankApplicationsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BankApplicationsService>;
}
