import { HttpClient, HttpHeaders, HttpResponse, HttpEvent, HttpParameterCodec, HttpContext } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ApplicationListIdpModel } from '../model/applicationList';
import { ApplicationWithSecretIdpModel } from '../model/applicationWithSecret';
import { PostOrganizationApplicationIdpModel } from '../model/postOrganizationApplication';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare class OrganizationApplicationsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    encoder: HttpParameterCodec;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    private addToHttpParams;
    private addToHttpParamsRecursive;
    /**
     * Create organization application
     * Create an organization OAuth2 application.  Required scope: **organization_applications:execute**
     * @param postOrganizationApplicationIdpModel
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createOrganizationApplication(postOrganizationApplicationIdpModel: PostOrganizationApplicationIdpModel, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<ApplicationWithSecretIdpModel>;
    createOrganizationApplication(postOrganizationApplicationIdpModel: PostOrganizationApplicationIdpModel, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<ApplicationWithSecretIdpModel>>;
    createOrganizationApplication(postOrganizationApplicationIdpModel: PostOrganizationApplicationIdpModel, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<ApplicationWithSecretIdpModel>>;
    /**
     * Delete organization application
     * Deletes an application.Required scope: **organization_applications:execute**
     * @param clientId Identifier for the application.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteOrganizationApplication(clientId: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<any>;
    deleteOrganizationApplication(clientId: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<any>>;
    deleteOrganizationApplication(clientId: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<any>>;
    /**
     * List organization applications
     * Retrieve a list of organization OAuth2 applications.  Required scope: **organizations:read**
     * @param page The page index to retrieve.
     * @param perPage The number of entities per page to return.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    listOrganizationApplications(page?: string, perPage?: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<ApplicationListIdpModel>;
    listOrganizationApplications(page?: string, perPage?: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpResponse<ApplicationListIdpModel>>;
    listOrganizationApplications(page?: string, perPage?: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
        context?: HttpContext;
    }): Observable<HttpEvent<ApplicationListIdpModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<OrganizationApplicationsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<OrganizationApplicationsService>;
}
